@@ -4,8 +4,12 @@
 # IMPORT ALL PACKAGES
 from shuttle.cli import click
 
-from .signature import sign
+from .htlc import htlc
+from .fund import fund
+from .claim import claim
+from .refund import refund
 from .decode import decode
+from .signature import sign
 from .submit import submit
 
 
@@ -15,9 +19,11 @@ def bytom():
     pass
 
 
-# Adding bytom sign
-bytom.add_command(sign)
-# Adding bytom decoder
+# Adding bytom commands
+bytom.add_command(htlc)
+bytom.add_command(fund)
+bytom.add_command(claim)
+bytom.add_command(refund)
 bytom.add_command(decode)
-# Adding bytom submit
+bytom.add_command(sign)
 bytom.add_command(submit)
