@@ -3,7 +3,7 @@
 from btcpy.structs.script import P2pkhScript, P2shScript
 from btcpy.structs.transaction import Sequence, MutableTransaction
 from btcpy.structs.address import Address
-from btcpy.setup import setup
+from btcpy.setup import setup as stp
 from base64 import b64encode, b64decode
 
 import cryptos
@@ -42,10 +42,10 @@ def decode_transaction_raw(tx_raw):
         tx_raw = json.loads(b64decode(str(tx_raw).encode()).decode())
     except (binascii.Error, json.decoder.JSONDecodeError) as _error:
         raise ValueError("invalid bitcoin transaction raw")
-    if "type" not in tx_raw and not str(tx_raw["type"]).startswith("bitcoin"):
+    if "type" not in tx_raw or not str(tx_raw["type"]).startswith("bitcoin"):
         raise ValueError("invalid bitcoin transaction raw")
     # Setting testnet
-    setup(tx_raw["network"], strict=True)
+    stp(tx_raw["network"], strict=True)
     tx = MutableTransaction.unhexlify(tx_raw["raw"])
     return dict(
         fee=tx_raw["fee"],
@@ -58,13 +58,12 @@ def decode_transaction_raw(tx_raw):
 # Submit payment from blockcypher
 def submit_payment(tx_raw, network="testnet", timeout=bitcoin["timeout"]):
     if isinstance(tx_raw, str):
-        tx = json.dumps(dict(tx=tx_raw))
-        parameter = dict(token=bitcoin[network]["blockcypher"]["token"])
-        response = requests.post(url=bitcoin[network]["blockcypher"]["url"] + "/txs/push",
-                                 data=tx, params=parameter, headers=headers, timeout=timeout)
+        tx = json.dumps(dict(hex=tx_raw))
+        response = requests.post(url=bitcoin[network]["smartbit"] + "/pushtx",
+                                 data=tx, headers=headers, timeout=timeout)
         if "error" in response.json():
-            raise APIError(response.json()["error"])
-        return response.json()["tx"]
+            raise APIError(response.json()["error"]["message"])
+        return response.json()
     raise TypeError("transaction raw must be string format!")
 
 
@@ -87,7 +86,7 @@ def submit_transaction_raw(tx_raw):
         decoded_tx_raw = json.loads(b64decode(str(tx_raw).encode()).decode())
     except (binascii.Error, json.decoder.JSONDecodeError) as _error:
         raise ValueError("invalid bitcoin transaction raw")
-    if "type" not in decoded_tx_raw and not str(decoded_tx_raw["type"]).startswith("bitcoin"):
+    if "type" not in decoded_tx_raw or not str(decoded_tx_raw["type"]).startswith("bitcoin"):
         raise ValueError("invalid bitcoin transaction raw")
     submitted = submit_payment(
         tx_raw=decoded_tx_raw["raw"],
@@ -96,14 +95,14 @@ def submit_transaction_raw(tx_raw):
     return dict(
         fee=decoded_tx_raw["fee"],
         type=decoded_tx_raw["type"],
-        tx_id=submitted["hash"],
+        tx_id=submitted["txid"],
         network=decoded_tx_raw["network"],
         date=str(datetime.datetime.utcnow())
     )
 
 
 # Checking address
-def is_address(address, network="testnet"):
+def is_address(address, network=None):
     """
     Check bitcoin address.
 
@@ -119,6 +118,13 @@ def is_address(address, network="testnet"):
     """
 
     if isinstance(address, str):
+        if network is None:
+            for boolean in [True, False]:
+                valid = False
+                if cryptos.Bitcoin(testnet=boolean).is_address(address):
+                    valid = True
+                    break
+            return valid
         if network == "testnet":
             return cryptos.Bitcoin(testnet=True).is_address(address)
         elif network == "mainnet":
